'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var wallets = require('@cpchain-foundation/wallets');
var react = require('react');
var recoil = require('recoil');

var cpchain = new wallets.CPChainExtensionWallet();
var key = "cpchain-foundation-wallet";
var walletState = recoil.atom({
    key: key,
    default: null,
});
/**
 * 创建 CPChain Wallet 对象
 * @returns
 */
function useWallet(_a) {
    var _b = _a === void 0 ? { cache: true } : _a, cache = _b.cache;
    var _c = recoil.useRecoilState(walletState), account = _c[0], setAccount = _c[1];
    var _d = react.useState(false), exists = _d[0], setExists = _d[1];
    react.useEffect(function () {
        try {
            wallets.extensionWalletExists().then(function (r) {
                setExists(r);
            }).catch(function (err) {
                console.error(err);
            });
        }
        catch (err) {
            console.error(err);
        }
    }, []);
    /**
     * 连接钱包
     *
     * Errors:
     * - NotFoundExtensionWallet 插件钱包不存在
     * - WalletNotUnlocked 钱包未解锁
     */
    var connect = function () {
        cpchain
            .connect()
            .then(function (account) {
            setAccount(account);
            if (cache) {
                localStorage.setItem(key, JSON.stringify(account));
            }
        })
            .catch(function (err) {
            throw err;
        });
    };
    /**
     * 退出登录
     */
    var disconnect = function () {
        setAccount(null);
        localStorage.setItem(key, "");
    };
    react.useEffect(function () {
        var str = localStorage.getItem(key);
        try {
            str && setAccount(JSON.parse(str));
        }
        catch (error) {
            setAccount(null);
            console.error(error);
        }
    }, []);
    return {
        exists: exists,
        connect: connect,
        disconnect: disconnect,
        account: account,
        cpchain: cpchain,
        connected: !!(account === null || account === void 0 ? void 0 : account.address),
    };
}

exports.useWallet = useWallet;
